@@ -47,13 +47,14 @@ progress <- function(
   ...,
   list = character(0),
   no_imported_objects = NULL,
-  path = getwd(),
-  search = TRUE,
-  cache = drake::get_cache(path = path, search = search, verbose = verbose),
+  path = NULL,
+  search = NULL,
+  cache = drake::drake_cache(path = path, verbose = verbose),
   verbose = 1L,
   jobs = 1,
   progress = NULL
 ) {
+  deprecate_search(search)
   if (is.null(cache)) {
     return(weak_tibble(target = character(0), progress = character(0)))
   }
@@ -119,11 +120,12 @@ progress <- function(
 #' })
 #' }
 running <- function(
-  path = getwd(),
-  search = TRUE,
-  cache = drake::get_cache(path = path, search = search, verbose = verbose),
+  path = NULL,
+  search = NULL,
+  cache = drake::drake_cache(path = path, verbose = verbose),
   verbose = 1L
 ) {
+  deprecate_search(search)
   prog <- progress(path = path, search = search, cache = cache)
   prog$target[prog$progress == "running"]
 }
@@ -154,12 +156,13 @@ running <- function(
 #' })
 #' }
 failed <- function(
-  path = getwd(),
-  search = TRUE,
-  cache = drake::get_cache(path = path, search = search, verbose = verbose),
+  path = NULL,
+  search = NULL,
+  cache = drake::drake_cache(path = path, verbose = verbose),
   verbose = 1L,
   upstream_only = NULL
 ) {
+  deprecate_search(search)
   if (!is.null(upstream_only)) {
     warning("argument upstream_only is deprecated.")
   }
@@ -176,7 +179,10 @@ get_progress_single <- function(target, cache) {
 }
 
 set_progress <- function(target, meta, value, config) {
-  if (!config$log_progress || (meta$imported %||% FALSE)) {
+  skip_progress <- !identical(config$running_make, TRUE) ||
+    !config$log_progress ||
+    (meta$imported %||% FALSE)
+  if (skip_progress) {
     return()
   }
   config$cache$duplicate(
