@@ -19,7 +19,9 @@ drake_meta_ <- function(target, config) {
   }
   # For imported files.
   if (meta$isfile) {
-    meta$mtime <- storage_mtime(decode_path(target, config))
+    path <- decode_path(target, config)
+    meta$mtime <- storage_mtime(path)
+    meta$size <- storage_size(path)
   }
   if (meta$trigger$command) {
     meta$command <- layout$command_standardized
@@ -38,6 +40,19 @@ drake_meta_ <- function(target, config) {
   meta
 }
 
+read_from_meta <- function(key, field, cache) {
+  object <- safe_get(
+    key = key,
+    namespace = "meta",
+    config = list(cache = cache)
+  )
+  if (field %in% names(object)) {
+    object[[field]]
+  } else {
+    NA_character_
+  }
+}
+
 dependency_hash <- function(target, config) {
   x <- config$layout[[target]]$deps_build
   deps <- c(x$globals, x$namespaced, x$loadd, x$readd)
@@ -123,11 +138,16 @@ output_file_hash <- function(
   )
 }
 
-rehash_storage <- function(target, config) {
+rehash_storage <- function(target, file = NULL, config) {
   if (!is_encoded_path(target)) {
     return(NA_character_)
   }
-  file <- decode_path(target, config)
+  if (is.null(file)) {
+    file <- decode_path(target, config)
+  }
+  if (is_url(file)) {
+    return(rehash_url(url = file))
+  }
   if (!file.exists(file)) {
     return(NA_character_)
   }
@@ -169,21 +189,46 @@ rehash_dir <- function(dir, config) {
   )
 }
 
-safe_rehash_storage <- function(target, config) {
-  if (file.exists(decode_path(target, config))) {
-    rehash_storage(target = target, config = config)
-  } else {
-    NA_character_
+rehash_url <- function(url) {
+  assert_pkg("curl")
+  headers <- NULL
+  if (!curl::has_internet()) {
+    # Tested in tests/testthat/test-always-skipped.R.
+    stop("no internet. Cannot check url: ", url, call. = FALSE) # nocov
+  }
+  req <- curl::curl_fetch_memory(url)
+  headers <- curl::parse_headers_list(req$headers)
+  assert_useful_headers(headers, url)
+  etag <- paste(headers[["etag"]], collapse = "")
+  mtime <- paste(headers[["last-modified"]], collapse = "")
+  return(paste(etag, mtime))
+}
+
+assert_useful_headers <- function(headers, url) {
+  if (!any(c("etag", "last-modified") %in% names(headers))) {
+    stop("no ETag or Last-Modified for url: ", url, call. = FALSE)
   }
 }
 
-should_rehash_storage <- function(filename, new_mtime, old_mtime,
-  size_cutoff) {
-  do_rehash <- storage_size(filename) < size_cutoff | new_mtime > old_mtime
-  if (safe_is_na(do_rehash)) {
-    do_rehash <- TRUE
-  }
-  do_rehash
+is_url <- function(x) {
+  grepl("^http://|^https://|^ftp://", x)
+}
+
+file_dep_exists <- function(x) {
+  file.exists(x) | is_url(x)
+}
+
+should_rehash_storage <- function(
+  size_cutoff,
+  new_mtime,
+  old_mtime,
+  new_size,
+  old_size
+) {
+  small <- (new_size < size_cutoff) %||NA% TRUE
+  touched <- (new_mtime > old_mtime) %||NA% TRUE
+  resized <- (abs(new_size - old_size) > drake_tol) %||NA% TRUE
+  small || touched || resized
 }
 
 storage_hash <- function(
@@ -194,37 +239,31 @@ storage_hash <- function(
   if (!is_encoded_path(target)) {
     return(NA_character_)
   }
-  filename <- decode_path(target, config)
-  if (!file.exists(filename)) {
+  file <- decode_path(target, config)
+  if (is_url(file)) {
+    return(rehash_storage(target = target, file = file, config = config))
+  }
+  if (!file.exists(file)) {
     return(NA_character_)
   }
-  old_mtime <- ifelse(
-    exists_in_subspace(
-      key = target,
-      subspace = "mtime",
-      namespace = "meta",
-      cache = config$cache
-    ),
-    get_from_subspace(
-      key = target,
-      subspace = "mtime",
-      namespace = "meta",
-      cache = config$cache
-    ),
-    -Inf
-  )
-  new_mtime <- storage_mtime(filename)
-  do_rehash <- should_rehash_storage(
-    filename = filename,
-    new_mtime = new_mtime,
-    old_mtime = old_mtime,
-    size_cutoff = size_cutoff)
-  old_hash_exists <- config$cache$exists(key = target)
-  if (do_rehash || !old_hash_exists) {
-    rehash_storage(target = target, config = config)
-  } else {
-    config$cache$get(key = target)
+  not_cached <- !config$cache$exists(key = target) ||
+    !config$cache$exists(key = target, namespace = "meta")
+  if (not_cached) {
+    return(rehash_storage(target = target, file = file, config = config))
   }
+  meta <- config$cache$get(key = target, namespace = "meta")
+  should_rehash <- should_rehash_storage(
+    size_cutoff = size_cutoff,
+    new_mtime = storage_mtime(file),
+    old_mtime = meta$mtime %||% -Inf,
+    new_size = storage_size(file),
+    old_size = meta$size
+  )
+  ifelse (
+    should_rehash,
+    rehash_storage(target = target, config = config),
+    config$cache$get(key = target)
+  )
 }
 
 storage_mtime <- function(x) {
@@ -239,7 +278,15 @@ storage_size <- function(x) {
   if (dir.exists(x)) {
     dir_size(x)
   } else {
+    file_size(x)
+  }
+}
+
+file_size <- function(x) {
+  if (file.exists(x)) {
     file.size(x)
+  } else {
+    NA_real_
   }
 }
 
@@ -263,6 +310,6 @@ dir_size <- function(x) {
     recursive = TRUE,
     include.dirs = FALSE
   )
-  sizes <- vapply(files, file.size, FUN.VALUE = numeric(1))
+  sizes <- vapply(files, file_size, FUN.VALUE = numeric(1))
   max(sizes %||% 0)
 }
