@@ -20,9 +20,9 @@
 #' })
 #' }
 drake_get_session_info <- function(
-  path = getwd(),
-  search = TRUE,
-  cache = drake::get_cache(path = path, search = search, verbose = verbose),
+  path = NULL,
+  search = NULL,
+  cache = drake::drake_cache(path = path, verbose = verbose),
   verbose = 1L
 ) {
   if (is.null(cache)) {
@@ -32,9 +32,9 @@ drake_get_session_info <- function(
 }
 
 drake_set_session_info <- function(
-  path = getwd(),
-  search = TRUE,
-  cache = drake::get_cache(path = path, search = search, verbose = verbose),
+  path = NULL,
+  search = NULL,
+  cache = drake::drake_cache(path = path, verbose = verbose),
   verbose = 1L,
   full = TRUE
 ) {
@@ -80,7 +80,10 @@ conclude_session <- function(config) {
     jobs = config$jobs_preprocess
   )
   remove(list = names(config$eval), envir = config$eval)
-  log_msg("done", config = config)
+  config$cache$flush_cache()
+  if (config$garbage_collection) {
+    gc()
+  }
   invisible()
 }
 
