@@ -87,7 +87,7 @@ redecode_namespaced <- redecode_path
 
 display_key <- function(x, config) {
   if (is_encoded_path(x)) {
-    sprintf("file %s", decode_path(x = x, config = config))
+    display_path(x = x, config = config)
   } else if (is_encoded_namespaced(x)) {
     sprintf("%s", decode_namespaced(x = x, config = config))
   } else {
@@ -95,6 +95,15 @@ display_key <- function(x, config) {
   }
 }
 
+display_path <- function(x, config) {
+  path <- decode_path(x = x, config = config)
+  if (is_url(path)) {
+    sprintf("url %s", path)
+  } else {
+    sprintf("file %s", path)
+  }
+}
+
 #' @title Tell `drake` that you want information
 #'   on a *file* (target or import), not an ordinary object.
 #' @description This function simply wraps literal double quotes around
