@@ -83,11 +83,11 @@ test_with_dir("clean in full build.", {
   config <- dbug()
   make(config$plan, envir = config$envir, verbose = 0L)
   expect_true("final" %in% config$cache$list())
-  clean(final, search = TRUE)
+  clean(final)
   expect_false("final" %in% config$cache$list())
-  clean(search = TRUE)
+  clean()
   expect_equal(config$cache$list(), character(0))
   expect_true(file.exists(default_cache_path()))
-  clean(search = TRUE, destroy = TRUE)
+  clean(destroy = TRUE)
   expect_false(file.exists(default_cache_path()))
 })
