@@ -37,7 +37,7 @@ test_with_dir("visNetwork dep graph does not fail if input file is binary", {
   skip_if_not_installed("visNetwork")
   x <- drake_plan(y = readRDS(file_in("input.rds")))
   saveRDS(as.list(datasets::mtcars), "input.rds")
-  con <- drake_config(x, verbose = FALSE)
+  con <- drake_config(x, verbose = 0L)
   expect_silent(out <- vis_drake_graph(con))
   unlink("input.rds", force = TRUE)
 })
@@ -51,7 +51,8 @@ test_with_dir("ggraphs", {
   load_mtcars_example()
   config <- drake_config(
     my_plan, cache = storr::storr_environment(), session_info = FALSE)
-  gg <- drake_ggraph(config)
+  gg <- drake_ggraph(config, label_nodes = FALSE)
+  gg <- drake_ggraph(config, label_nodes = TRUE)
   expect_true(inherits(gg, "ggplot"))
   make(config = config)
   gg <- drake_ggraph(config)
